@@ -782,7 +782,14 @@ class GenotypeNetwork(igraph.Graph):
 #    print network.summary()
         self.__calculate_network_properties__()
 #        logging.debug ([(att, att in self.attributes()) for att in report_attributes])
-        report_values = [str(self[att]) for att in report_attributes]
+        report_values = []
+        for att in report_attributes:
+            if att not in self.attributes():
+#                print '\n - '.join(self.attributes())
+                raise InvalidNetworkAttribute('Invalid attribute: {0}'.format(att), self.attributes())
+            else:
+                report_values.append(str(self[att]))
+#        report_values = [str(self[att]) for att in report_attributes]
         report = ' '.join(report_values)
         return report
 
@@ -838,7 +845,7 @@ class GenotypeNetwork(igraph.Graph):
                     # if the attribute name starts with network_ (e.g. network_name), get the network property.
                     node_attributes.append(str(round_if_float(self[attribute[8:]])))
                 else:
-                    raise GenotypeNetworkAttributeError('attribute "{0}" not found'.format(attribute))
+                    raise InvalidNetworkAttribute('attribute "{0}" not found'.format(attribute), self.attributes())
             report += '\t'.join(node_attributes) + '\n'
 #            print report_values            
         return report[:-1]
