@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 """
-This script takes as input a VCF file, and generates a report of the Genotype Network properties from it.
+VCF2Networks is a python script that allows to calculate Genotype Networks from a Variant Call Format (VCF) file.
+
+Read more about it, and follow the tutorial, at https://bitbucket.org/dalloliogm/vcf2networks
 
 
 """
@@ -27,7 +29,7 @@ from custom_exceptions import *
 from __init__ import __version__
 
 def get_options():
-    parser = argparse.ArgumentParser(#            description=__doc__,
+    parser = argparse.ArgumentParser(description=__doc__,
             formatter_class=argparse.ArgumentDefaultsHelpFormatter,
             prog="vcf2networks")
 #    config_group = argparse.OptionGroup(parser, "Configuration options. Required")
@@ -39,7 +41,7 @@ def get_options():
             help='File containing the classification of individuals into populations. This must be a tab-separated file, in which the first column is the individual ID, the second is the population, the third is the continental group (or other classification), and the other columns contain classification in phenotypes, one per column. This can also defined in the parameters file (--config). Required.', 
             default="")
     config_group.add_argument('-c', '--config', '--params', dest='params_file', 
-            help='File containing many parameters of the analysis. In particular, the list of network properties that will be included in the output report. Required.', 
+            help='File containing many parameters of the analysis. In particular, the list of network properties that will be included in the output report. This option is not mandatory, but if it is not defined, a warning message will be shown.', 
             default=False)
     config_group.add_argument('-p', '--property', '--phenotype', dest='phenotype', 
             help='Phenotype column used to define the Genotype Networks (e.g. population, disease status, eye color, etc..). When this option is defined, the output will consist of one line for the global population, plus one line for each Genotype Network built using only individuals having the same phenotype.', 
